==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/AwsCloudTrailDataConnectorDataTypesLogsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DataTypeState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Logs data type.
 * @property state Describe whether this data type connection is enabled or not.
 */
public data class AwsCloudTrailDataConnectorDataTypesLogsArgs(
    public val state: Output<Either<String, DataTypeState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs =
        com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AwsCloudTrailDataConnectorDataTypesLogsArgs].
 */
@PulumiTagMarker
public class AwsCloudTrailDataConnectorDataTypesLogsArgsBuilder internal constructor() {
    private var state: Output<Either<String, DataTypeState>>? = null

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("fokjbthbdwygigbx")
    public suspend fun state(`value`: Output<Either<String, DataTypeState>>) {
        this.state = value
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("jaadjurpongnkfvr")
    public suspend fun state(`value`: Either<String, DataTypeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("mpvxanoakpfcudpa")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("bejvkhpvoqaxxldf")
    public fun state(`value`: DataTypeState) {
        val toBeMapped = Either.ofRight<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): AwsCloudTrailDataConnectorDataTypesLogsArgs =
        AwsCloudTrailDataConnectorDataTypesLogsArgs(
            state = state,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/AwsCloudTrailDataConnectorDataTypesLogsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs.builder
import com.pulumi.azurenative.securityinsights.kotlin.enums.DataTypeState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Logs data type.
 * @property state Describe whether this data type connection is enabled or not.
 */
public data class AwsCloudTrailDataConnectorDataTypesLogsArgs(
    public val state: Output<Either<String, DataTypeState>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs =
        com.pulumi.azurenative.securityinsights.inputs.AwsCloudTrailDataConnectorDataTypesLogsArgs.builder()
            .state(
                state?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AwsCloudTrailDataConnectorDataTypesLogsArgs].
 */
@PulumiTagMarker
public class AwsCloudTrailDataConnectorDataTypesLogsArgsBuilder internal constructor() {
    private var state: Output<Either<String, DataTypeState>>? = null

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("dhjawaosgsmbqwyx")
    public suspend fun state(`value`: Output<Either<String, DataTypeState>>) {
        this.state = value
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("tleeumhfkgdkqaoq")
    public suspend fun state(`value`: Either<String, DataTypeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("yhnvocgiibagxaei")
    public fun state(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    /**
     * @param value Describe whether this data type connection is enabled or not.
     */
    @JvmName("ehbvysocgjclwtrs")
    public fun state(`value`: DataTypeState) {
        val toBeMapped = Either.ofRight<String, DataTypeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.state = mapped
    }

    internal fun build(): AwsCloudTrailDataConnectorDataTypesLogsArgs =
        AwsCloudTrailDataConnectorDataTypesLogsArgs(
            state = state,
        )
}
